Manifold Learning
=========

.. figure:: icons/manifold-learning.png

Nonlinear dimensionality reduction.

Signals
-------

**Inputs**:

-  **Data**

   Data set.

**Outputs**:

-  **Transformed Data**

   Transformed data set.

Description
-----------

A widget for nonlinear dimensionality reduction.
